==> galleon-parent-2.0.2.Final-source-release.zip: galleon-parent-2.0.2.Final/core/src/test/java/org/jboss/galleon/config/feature/group/MultipleInclusionOfFeatureGroupConfigBranchedPerSpecTestCase.java <==
/*
 * Copyright 2016-2018 Red Hat, Inc. and/or its affiliates
 * and other contributors as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.galleon.config.feature.group;

import org.jboss.galleon.universe.galleon1.LegacyGalleon1Universe;
import org.jboss.galleon.universe.FeaturePackLocation.FPID;
import org.jboss.galleon.ProvisioningException;
import org.jboss.galleon.config.ConfigModel;
import org.jboss.galleon.config.FeatureConfig;
import org.jboss.galleon.config.FeatureGroup;
import org.jboss.galleon.config.FeaturePackConfig;
import org.jboss.galleon.creator.FeaturePackCreator;
import org.jboss.galleon.runtime.ResolvedFeatureId;
import org.jboss.galleon.spec.FeatureId;
import org.jboss.galleon.spec.FeatureParameterSpec;
import org.jboss.galleon.spec.FeatureReferenceSpec;
import org.jboss.galleon.spec.FeatureSpec;
import org.jboss.galleon.state.ProvisionedFeaturePack;
import org.jboss.galleon.state.ProvisionedState;
import org.jboss.galleon.test.PmInstallFeaturePackTestBase;
import org.jboss.galleon.xml.ProvisionedConfigBuilder;
import org.jboss.galleon.xml.ProvisionedFeatureBuilder;

/**
 *
 * @author Alexey Loubyansky
 */
public class MultipleInclusionOfFeatureGroupConfigBranchedPerSpecTestCase extends PmInstallFeaturePackTestBase {

    private static final FPID FP_GAV = LegacyGalleon1Universe.newFPID("org.jboss.pm.test:fp1", "1", "1.0.0.Final");

    @Override
    protected void createFeaturePacks(FeaturePackCreator creator) throws ProvisioningException {
        creator
        .newFeaturePack(FP_GAV)
            .addSpec(FeatureSpec.builder("specA")
                    .addParam(FeatureParameterSpec.createId("a"))
                    .addParam(FeatureParameterSpec.create("prop", true))
                    .build())
            .addSpec(FeatureSpec.builder("specB")
                    .addFeatureRef(FeatureReferenceSpec.create("specA"))
                    .addParam(FeatureParameterSpec.createId("a"))
                    .addParam(FeatureParameterSpec.createId("b"))
                    .addParam(FeatureParameterSpec.create("prop", true))
                    .build())
            .addSpec(FeatureSpec.builder("specC")
                    .addFeatureRef(FeatureReferenceSpec.create("specA"))
                    .addFeatureRef(FeatureReferenceSpec.create("specB"))
                    .addParam(FeatureParameterSpec.createId("a"))
                    .addParam(FeatureParameterSpec.createId("b"))
                    .addParam(FeatureParameterSpec.createId("c"))
                    .addParam(FeatureParameterSpec.create("prop", true))
                    .build())
            .addFeatureGroup(FeatureGroup.builder("fgC")
                    .addFeature(
                            new FeatureConfig("specC")
                            .setParam("c", "c1")
                            .setParam("prop", "fgC"))
                    .addFeature(
                            new FeatureConfig("specC")
                            .setParam("c", "c2")
                            .setParam("prop", "fgC"))
                    .build())
            .addFeatureGroup(FeatureGroup.builder("fgB")
                    .addFeature(
                            new FeatureConfig("specB")
                            .setParam("b", "b1")
                            .setParam("prop", "fgB")
                            .addFeatureGroup(FeatureGroup.builder("fgC")
                                    .setInheritFeatures(true)
                                    .includeFeature(FeatureId.create("specC", "c", "c1"), new FeatureConfig().setParam("prop", "fgB"))
                                    .build()))
                    .addFeature(
                            new FeatureConfig("specB")
                            .setParam("b", "b2")
                            .setParam("prop", "fgB")
                            .addFeatureGroup(FeatureGroup.builder("fgC")
                                    .setInheritFeatures(true)
                                    .includeFeature(FeatureId.create("specC", "c", "c1"), new FeatureConfig().setParam("prop", "fgB"))
                                    .build()))
                    .build())
            .addFeatureGroup(FeatureGroup.builder("fgA")
                    .addFeature(
                            new FeatureConfig("specA")
                            .setParam("a", "a1")
                            .setParam("prop", "fgA")
                            .addFeatureGroup(FeatureGroup.builder("fgB")
                                    .setInheritFeatures(true)
                                    .includeFeature(FeatureId.create("specB", "b", "b1"), new FeatureConfig().setParam("prop", "fgA"))
                                    .includeFeature(FeatureId.builder("specC").setParam("b", "b1").setParam("c", "c1").build(), new FeatureConfig().setParam("prop", "fgA"))
                                    .build()))
                    .addFeature(
                            new FeatureConfig("specA")
                            .setParam("a", "a2")
                            .setParam("prop", "fgA")
                            .addFeatureGroup(FeatureGroup.builder("fgB")
                                    .setInheritFeatures(true)
                                    .includeFeature(FeatureId.create("specB", "b", "b1"), new FeatureConfig().setParam("prop", "fgA"))
                                    .includeFeature(FeatureId.builder("specC").setParam("b", "b1").setParam("c", "c1").build(), new FeatureConfig().setParam("prop", "fgA"))
                                    .build()))
                    .build())
            .addConfig(ConfigModel.builder()
                    .setProperty(ConfigModel.BRANCH_PER_SPEC, "true")
                    .addFeatureGroup(FeatureGroup.forGroup("fgA"))
                    .build())
            .getCreator()
        .install();
    }

    @Override
    protected FeaturePackConfig featurePackConfig() {
        return FeaturePackConfig.forLocation(FP_GAV.getLocation());
    }

    @Override
    protected ProvisionedState provisionedState() throws ProvisioningException {
        return ProvisionedState.builder()
                .addFeaturePack(ProvisionedFeaturePack.forFPID(FP_GAV))
                .addConfig(ProvisionedConfigBuilder.builder()
                        .setProperty(ConfigModel.BRANCH_PER_SPEC, "true")
                        .addFeature(ProvisionedFeatureBuilder.builder(ResolvedFeatureId.create(FP_GAV.getProducer(), "specA", "a", "a1"))
                                .setConfigParam("prop", "fgA")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(ResolvedFeatureId.create(FP_GAV.getProducer(), "specA", "a", "a2"))
                                .setConfigParam("prop", "fgA")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(ResolvedFeatureId.builder(FP_GAV.getProducer(), "specB").setParam("a", "a1").setParam("b", "b1").build())
                                .setConfigParam("prop", "fgA")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(ResolvedFeatureId.builder(FP_GAV.getProducer(), "specB").setParam("a", "a1").setParam("b", "b2").build())
                                .setConfigParam("prop", "fgB")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(ResolvedFeatureId.builder(FP_GAV.getProducer(), "specB").setParam("a", "a2").setParam("b", "b1").build())
                                .setConfigParam("prop", "fgA")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(ResolvedFeatureId.builder(FP_GAV.getProducer(), "specB").setParam("a", "a2").setParam("b", "b2").build())
                                .setConfigParam("prop", "fgB")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(
                                ResolvedFeatureId.builder(FP_GAV.getProducer(), "specC").setParam("a", "a1").setParam("b", "b1").setParam("c", "c1").build())
                                .setConfigParam("prop", "fgA")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(
                                ResolvedFeatureId.builder(FP_GAV.getProducer(), "specC").setParam("a", "a1").setParam("b", "b1").setParam("c", "c2").build())
                                .setConfigParam("prop", "fgC")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(
                                ResolvedFeatureId.builder(FP_GAV.getProducer(), "specC").setParam("a", "a1").setParam("b", "b2").setParam("c", "c1").build())
                                .setConfigParam("prop", "fgB")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(
                                ResolvedFeatureId.builder(FP_GAV.getProducer(), "specC").setParam("a", "a1").setParam("b", "b2").setParam("c", "c2").build())
                                .setConfigParam("prop", "fgC")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(
                                ResolvedFeatureId.builder(FP_GAV.getProducer(), "specC").setParam("a", "a2").setParam("b", "b1").setParam("c", "c1").build())
                                .setConfigParam("prop", "fgA")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(
                                ResolvedFeatureId.builder(FP_GAV.getProducer(), "specC").setParam("a", "a2").setParam("b", "b1").setParam("c", "c2").build())
                                .setConfigParam("prop", "fgC")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(
                                ResolvedFeatureId.builder(FP_GAV.getProducer(), "specC").setParam("a", "a2").setParam("b", "b2").setParam("c", "c1").build())
                                .setConfigParam("prop", "fgB")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(
                                ResolvedFeatureId.builder(FP_GAV.getProducer(), "specC").setParam("a", "a2").setParam("b", "b2").setParam("c", "c2").build())
                                .setConfigParam("prop", "fgC")
                                .build())

                        .build())
                .build();
    }
}

==> galleon-parent-4.0.4.Final-source-release.zip: galleon-parent-4.0.4.Final/core/src/test/java/org/jboss/galleon/config/feature/group/MultipleInclusionOfFeatureGroupConfigBranchedPerSpecTestCase.java <==
/*
 * Copyright 2016-2019 Red Hat, Inc. and/or its affiliates
 * and other contributors as indicated by the @author tags.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jboss.galleon.config.feature.group;

import org.jboss.galleon.universe.galleon1.LegacyGalleon1Universe;
import org.jboss.galleon.universe.FeaturePackLocation.FPID;
import org.jboss.galleon.ProvisioningException;
import org.jboss.galleon.config.ConfigModel;
import org.jboss.galleon.config.FeatureConfig;
import org.jboss.galleon.config.FeatureGroup;
import org.jboss.galleon.config.FeaturePackConfig;
import org.jboss.galleon.creator.FeaturePackCreator;
import org.jboss.galleon.runtime.ResolvedFeatureId;
import org.jboss.galleon.spec.FeatureId;
import org.jboss.galleon.spec.FeatureParameterSpec;
import org.jboss.galleon.spec.FeatureReferenceSpec;
import org.jboss.galleon.spec.FeatureSpec;
import org.jboss.galleon.state.ProvisionedFeaturePack;
import org.jboss.galleon.state.ProvisionedState;
import org.jboss.galleon.test.PmInstallFeaturePackTestBase;
import org.jboss.galleon.xml.ProvisionedConfigBuilder;
import org.jboss.galleon.xml.ProvisionedFeatureBuilder;

/**
 *
 * @author Alexey Loubyansky
 */
public class MultipleInclusionOfFeatureGroupConfigBranchedPerSpecTestCase extends PmInstallFeaturePackTestBase {

    private static final FPID FP_GAV = LegacyGalleon1Universe.newFPID("org.jboss.pm.test:fp1", "1", "1.0.0.Final");

    @Override
    protected void createFeaturePacks(FeaturePackCreator creator) throws ProvisioningException {
        creator
        .newFeaturePack(FP_GAV)
            .addFeatureSpec(FeatureSpec.builder("specA")
                    .addParam(FeatureParameterSpec.createId("a"))
                    .addParam(FeatureParameterSpec.create("prop", true))
                    .build())
            .addFeatureSpec(FeatureSpec.builder("specB")
                    .addFeatureRef(FeatureReferenceSpec.create("specA"))
                    .addParam(FeatureParameterSpec.createId("a"))
                    .addParam(FeatureParameterSpec.createId("b"))
                    .addParam(FeatureParameterSpec.create("prop", true))
                    .build())
            .addFeatureSpec(FeatureSpec.builder("specC")
                    .addFeatureRef(FeatureReferenceSpec.create("specA"))
                    .addFeatureRef(FeatureReferenceSpec.create("specB"))
                    .addParam(FeatureParameterSpec.createId("a"))
                    .addParam(FeatureParameterSpec.createId("b"))
                    .addParam(FeatureParameterSpec.createId("c"))
                    .addParam(FeatureParameterSpec.create("prop", true))
                    .build())
            .addFeatureGroup(FeatureGroup.builder("fgC")
                    .addFeature(
                            new FeatureConfig("specC")
                            .setParam("c", "c1")
                            .setParam("prop", "fgC"))
                    .addFeature(
                            new FeatureConfig("specC")
                            .setParam("c", "c2")
                            .setParam("prop", "fgC"))
                    .build())
            .addFeatureGroup(FeatureGroup.builder("fgB")
                    .addFeature(
                            new FeatureConfig("specB")
                            .setParam("b", "b1")
                            .setParam("prop", "fgB")
                            .addFeatureGroup(FeatureGroup.builder("fgC")
                                    .setInheritFeatures(true)
                                    .includeFeature(FeatureId.create("specC", "c", "c1"), new FeatureConfig().setParam("prop", "fgB"))
                                    .build()))
                    .addFeature(
                            new FeatureConfig("specB")
                            .setParam("b", "b2")
                            .setParam("prop", "fgB")
                            .addFeatureGroup(FeatureGroup.builder("fgC")
                                    .setInheritFeatures(true)
                                    .includeFeature(FeatureId.create("specC", "c", "c1"), new FeatureConfig().setParam("prop", "fgB"))
                                    .build()))
                    .build())
            .addFeatureGroup(FeatureGroup.builder("fgA")
                    .addFeature(
                            new FeatureConfig("specA")
                            .setParam("a", "a1")
                            .setParam("prop", "fgA")
                            .addFeatureGroup(FeatureGroup.builder("fgB")
                                    .setInheritFeatures(true)
                                    .includeFeature(FeatureId.create("specB", "b", "b1"), new FeatureConfig().setParam("prop", "fgA"))
                                    .includeFeature(FeatureId.builder("specC").setParam("b", "b1").setParam("c", "c1").build(), new FeatureConfig().setParam("prop", "fgA"))
                                    .build()))
                    .addFeature(
                            new FeatureConfig("specA")
                            .setParam("a", "a2")
                            .setParam("prop", "fgA")
                            .addFeatureGroup(FeatureGroup.builder("fgB")
                                    .setInheritFeatures(true)
                                    .includeFeature(FeatureId.create("specB", "b", "b1"), new FeatureConfig().setParam("prop", "fgA"))
                                    .includeFeature(FeatureId.builder("specC").setParam("b", "b1").setParam("c", "c1").build(), new FeatureConfig().setParam("prop", "fgA"))
                                    .build()))
                    .build())
            .addConfig(ConfigModel.builder()
                    .setName("main")
                    .setProperty(ConfigModel.BRANCH_PER_SPEC, "true")
                    .addFeatureGroup(FeatureGroup.forGroup("fgA"))
                    .build())
            .getCreator()
        .install();
    }

    @Override
    protected FeaturePackConfig featurePackConfig() {
        return FeaturePackConfig.forLocation(FP_GAV.getLocation());
    }

    @Override
    protected ProvisionedState provisionedState() throws ProvisioningException {
        return ProvisionedState.builder()
                .addFeaturePack(ProvisionedFeaturePack.forFPID(FP_GAV))
                .addConfig(ProvisionedConfigBuilder.builder()
                        .setName("main")
                        .setProperty(ConfigModel.BRANCH_PER_SPEC, "true")
                        .addFeature(ProvisionedFeatureBuilder.builder(ResolvedFeatureId.create(FP_GAV.getProducer(), "specA", "a", "a1"))
                                .setConfigParam("prop", "fgA")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(ResolvedFeatureId.create(FP_GAV.getProducer(), "specA", "a", "a2"))
                                .setConfigParam("prop", "fgA")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(ResolvedFeatureId.builder(FP_GAV.getProducer(), "specB").setParam("a", "a1").setParam("b", "b1").build())
                                .setConfigParam("prop", "fgA")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(ResolvedFeatureId.builder(FP_GAV.getProducer(), "specB").setParam("a", "a1").setParam("b", "b2").build())
                                .setConfigParam("prop", "fgB")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(ResolvedFeatureId.builder(FP_GAV.getProducer(), "specB").setParam("a", "a2").setParam("b", "b1").build())
                                .setConfigParam("prop", "fgA")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(ResolvedFeatureId.builder(FP_GAV.getProducer(), "specB").setParam("a", "a2").setParam("b", "b2").build())
                                .setConfigParam("prop", "fgB")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(
                                ResolvedFeatureId.builder(FP_GAV.getProducer(), "specC").setParam("a", "a1").setParam("b", "b1").setParam("c", "c1").build())
                                .setConfigParam("prop", "fgA")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(
                                ResolvedFeatureId.builder(FP_GAV.getProducer(), "specC").setParam("a", "a1").setParam("b", "b1").setParam("c", "c2").build())
                                .setConfigParam("prop", "fgC")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(
                                ResolvedFeatureId.builder(FP_GAV.getProducer(), "specC").setParam("a", "a1").setParam("b", "b2").setParam("c", "c1").build())
                                .setConfigParam("prop", "fgB")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(
                                ResolvedFeatureId.builder(FP_GAV.getProducer(), "specC").setParam("a", "a1").setParam("b", "b2").setParam("c", "c2").build())
                                .setConfigParam("prop", "fgC")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(
                                ResolvedFeatureId.builder(FP_GAV.getProducer(), "specC").setParam("a", "a2").setParam("b", "b1").setParam("c", "c1").build())
                                .setConfigParam("prop", "fgA")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(
                                ResolvedFeatureId.builder(FP_GAV.getProducer(), "specC").setParam("a", "a2").setParam("b", "b1").setParam("c", "c2").build())
                                .setConfigParam("prop", "fgC")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(
                                ResolvedFeatureId.builder(FP_GAV.getProducer(), "specC").setParam("a", "a2").setParam("b", "b2").setParam("c", "c1").build())
                                .setConfigParam("prop", "fgB")
                                .build())
                        .addFeature(ProvisionedFeatureBuilder.builder(
                                ResolvedFeatureId.builder(FP_GAV.getProducer(), "specC").setParam("a", "a2").setParam("b", "b2").setParam("c", "c2").build())
                                .setConfigParam("prop", "fgC")
                                .build())

                        .build())
                .build();
    }
}
